#!/bin/sh
#
# Copyright 2006 Hewlett-Packard Development Company, L.P.
# No photocopying.
#
# Script to delete CIM classes from a local repository.  By default
# the root/cimv2 namespace is used. 
#
# Usage: deleteclass.sh [-v] [-n NAMESPACE] CLASSNAME
#

# Usage info

usage() {
    echo "Usage: deleteclass.sh [-v] [-n NAMESPACE] CLASSNAME"
}

# Get command line args

verbose=0
namespace=root/cimv2

while getopts "vn:" options; do
    case $options in
	v) 
	    verbose=1
	    ;;
	n)
	    namespace=$OPTARG
	    ;;
	?)
	    usage
	    exit 1
	    ;;
    esac
done

shift `expr $OPTIND - 1`

# Must specify one classname to delete

if [ $# != 1 ]; then
    usage
    exit 1
fi

classname=$1

# Build an XML fragment for the specified namespace

for ns in `echo $namespace | sed "s/\// /g"`; do
    nsxml="${nsxml}<NAMESPACE NAME=\"$ns\"/>"
done

xml='
<?xml version="1.0" ?>
<CIM CIMVERSION="2.0" DTDVERSION="2.0">
  <MESSAGE ID="1001" PROTOCOLVERSION="1.0">
    <SIMPLEREQ>
      <IMETHODCALL NAME="DeleteClass">
        <LOCALNAMESPACEPATH>'${nsxml}'</LOCALNAMESPACEPATH>
        <IPARAMVALUE NAME="ClassName">
          <CLASSNAME NAME="'${classname}'"/>
        </IPARAMVALUE>
      </IMETHODCALL>
    </SIMPLEREQ>
  </MESSAGE>
</CIM>'

if [ $verbose = "1" ]; then
    echo $xml
fi

# Run wbemexec

if [ $verbose = "1" ]; then
    echo $xml | wbemexec
else
    echo $xml | wbemexec | grep ERROR
fi

exit $?
