#!/bin/bash
#
# Handle RPM installation and uninstallation, starting and stopping
# Pegasus as necessary.

RETVAL=0
PREFIX=$2

install_rpm() {
	# Start pegasus.
        /etc/init.d/tog-pegasus start &> /dev/null
        sleep 3
        /etc/init.d/tog-pegasus status &> /dev/null
        if [ $? != 0 ]; then
            echo "Failed to start tog-pegasus."
            return -1
        fi

        echo "Installing WBEM schema."
	# Install CIM schema in root/hpq namespace
	cimmof -uc -w -n root/hpq -I $PREFIX/mof/CIM2340 \
		$PREFIX/mof/CIM2340/cim_schema_2.34.0.mof

	# Install needed CIM schema in root/interop namespace
	cimmof -uc -w -n root/interop -I $PREFIX/mof/CIM2340 \
        $PREFIX/mof/cimv2340-coreinterop.mof
	
	# Install Qualifiers and SMX schema in root/hpq namespace
        cimmof -aE -uc -w -n root/hpq $PREFIX/mof/root/hpq/SMXQualifiers.mof
	
	for class in `cat $PREFIX/mof/moflist.root\#hpq`; do
		cimmof -aE -uc -w -n root/hpq -I $PREFIX/mof/root/hpq \
			$PREFIX/mof/root/hpq/$class.mof
	done
	
	# Install SMX schema in root/interop namespace
        cimmof -aE -uc -w -n root/interop $PREFIX/mof/root/hpq/SMXQualifiers.mof

	for class in `cat $PREFIX/mof/moflist.root\#interop`; do
		cimmof -uc -w -n root/interop -I $PREFIX/mof/root/interop \
	        	$PREFIX/mof/root/interop/$class.mof
	done	
	
        echo "Installing SMX provider."
	# Run ldconfig to update our entry in /etc/ld.so.conf.d
	ldconfig

	# Register providers
	cimmof -aE -uc -w -n root/PG_InterOp $PREFIX/reg/*R.mof
	
	# Create SMX_AutoStart indication subscription
	/opt/hp/hp-smx/bin/mkautostart
}

uninstall_rpm() {
        # make sure the tog-pegasus is started.
        # we started the tog-pegasus before call this function.    
        /etc/init.d/tog-pegasus status &> /dev/null
        if [[ $? != 0 ]]; then
            # it's not good to give error here.
            # but better later than nothing.
            echo "Failed to start tog-pegasus."
            # Stop here, the steps need a running pegasus.
            return -1
        fi

	/opt/hp/hp-smx/bin/rmsubs -y
        
	# Uninstall SMX schema in root/interop namespace
	echo "Uninstalling SMX schema in root/interop." 
        for class in `cat $PREFIX/mof/moflist-reversed.root\#interop`; do
        	$PREFIX/bin/deleteclass.sh -n root/interop $class
	done	

        # Remove providers.
        echo "Uninstalling SMX provider."
        for module in `cat $PREFIX/reg/*modulelist`; do
              cimprovider -rm $module > /dev/null 2>&1
	done

        # Stop tog-pegasus and remove the repository for root/hpq
        /etc/init.d/tog-pegasus stop &> /dev/null
        sleep 3
        /etc/init.d/tog-pegasus status &> /dev/null
        if [ $? != 3 ]; then
            echo "Failed to stop tog-pegasus."
            return -1
        fi
        
        echo "Removing SMX repository."
        rm -rf /var/lib/Pegasus/repository/root#hpq
        rm -rf /var/log/SMX-*.log

        /etc/init.d/tog-pegasus start &> /dev/null
        sleep 3
        /etc/init.d/tog-pegasus status &> /dev/null
        if [ $? != 0 ]; then
            echo "Failed to start tog-pegasus."
            return -1
        fi

	for module in `cimprovider -l | grep SMX`; do
		cimprovider -rm $module > /dev/null 2>&1
	done
}

case "$1" in

	install|uninstall)
		$1_rpm
        ;;

	*)
		echo "Usage: $0 {install|uninstall} {base directory}"
		RETVAL=2
        ;;
esac

exit $RETVAL
